@@ -20,6 +20,7 @@ subscription  JobCreated(
         alias
         type
         enabled
+        context # for rehydration
         schedule
         query
         lockRequired
@@ -39,3 +40,19 @@ subscription  JobCreated(
   }
 }
 '''
+
+JOB_UPDATED = '''
+subscription {
+  jobUpdated{
+    successful
+    messages{
+      field
+      message
+    }
+    result{
+      id
+      jobStatus
+    }
+  }
+}
+'''
\ No newline at end of file
